Struct archspec::schema::Microarchitecture
source · pub struct Microarchitecture {
pub from: Vec<String>,
pub vendor: String,
pub features: Vec<String>,
pub compilers: Option<HashMap<String, CompilerSet>>,
pub generation: Option<usize>,
}Expand description
Defines the attributes and requirements of a microarchitecture.
Fields
from: Vec<String>A list of the immediate microarchitectures that this one is considered to be derived from.
vendor: StringHuman-readable vendor name.
features: Vec<String>The CPU features that are required to exist on the system for it to be compatible with this microarchitecture.
compilers: Option<HashMap<String, CompilerSet>>Optional information on how to tell different compilers how to optimize for this microarchitecture.
generation: Option<usize>Generation of the microarchitecture, if relevant.